#ifndef CONVERTER_H_
#define CONVERTER_H_

/*
 * mtz2hkl - convert mtz-file to shelx HKL format
 * Copyright (C) 2008 Tim Gruene
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include <vector>
#include <string>

#include "Reflex.h"

#include <ccp4/cmtzlib.h>

class Converter
{
private:
	enum { DATA, SIGMA, RFREE, NUMCOLS };
	CMtz::MTZ* mtz_;
	std::string mtzfile_;
	std::string hklfile_;
	
	unsigned int index_data_;
	unsigned int index_sigma_;
	unsigned int index_rfree_;
	std::string label_data_;
	std::string label_sigma_;
	std::string label_rfree_;
		
	int value_rfree_;
	bool forceNoRfree_;

	int* columns_;
	
	bool data_are_intensities_;
	
	std::vector<Reflex> reflections_;
		
	int completeLabels();
	int readData();
	int scaleData();
	void squareData();
	unsigned int writeData();
	void printInfo(unsigned int numTestSet) const;
	
public:
	Converter(const std::string& mtzfile, const std::string& hklfile,
	          const std::string& label_data, const std::string& label_sigma,
	          const std::string& label_rfree, int value_rfree,
	          bool forceNoRfree);
	virtual ~Converter();
	//! do the 'trick'
	int convert(bool squareAmplitudes);
	
	//! print summary of mtz-struct
	int mtzinfo() const;
};

#endif /*CONVERTER_H_*/
