/*
 * mtz2hkl - convert mtz-file to shelx HKL format
 * Copyright (C) 2008 Tim Gruene
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include "Reflex.h"

#include <cmath>

Reflex::Reflex()
{
}

Reflex::Reflex(int h, int k, int l, float data, float sigma, int r):
 h_(h), k_(k), l_(l), data_(data), sigma_(sigma), rfree_(r) 
 {}
 
Reflex::~Reflex()
{
}

/**
 * Simple squaring of data (i.e. assuming it is Amplitude and Intensity
 * is required. Calculation:
 * \f$\sigma_I = 2 |F| \sigma_F\f$
 * \f$\data_I  = data_F^2\f$
 */
void Reflex::square()
{
	sigma_ *= 2.0*std::abs(data_);
	data_  *= data_;
}

bool greaterSigma(const Reflex& r1, const Reflex& r2){ return r1.sigma_ > r2.sigma_; }
bool lesserSigma (const Reflex& r1, const Reflex& r2){ return r1.sigma_ < r2.sigma_; }
