#ifndef REFLEX_H_
#define REFLEX_H_

/*
 * mtz2hkl - convert mtz-file to shelx HKL format
 * Copyright (C) 2008 Tim Gruene
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

class Reflex
{
private:
	int h_, k_, l_;
	float data_, sigma_;
	int rfree_;
public:
	Reflex();
	Reflex(int, int, int, float, float, int);
	virtual ~Reflex();
	void square();
	
	int h() const { return h_; } 
	int k() const { return k_; } 
	int l() const { return l_; }
	float data() const { return data_; }
	float sigma() const { return sigma_; }
	int rfree() const { return rfree_; }
	
	friend bool operator< (const Reflex& r1, const Reflex& r2){ return r1.data_ < r2.data_; }
	friend Reflex& operator* (const float& k, Reflex& r) {
		r.data_  *= k;
		r.sigma_ *= k;
		return r;
	}
	//! sorting based on sigma values
	friend bool greaterSigma(const Reflex& r1, const Reflex& r2);
	friend bool lesserSigma(const Reflex& r1, const Reflex& r2);
};
bool greaterSigma(const Reflex& r1, const Reflex& r2);
bool lesserSigma(const Reflex& r1, const Reflex& r2);
#endif /*REFLEX_H_*/
