#ifndef DEFINES_H_
#define DEFINES_H_

/*
 * mtz2hkl - convert mtz-file to shelx HKL format
 * Copyright (C) 2008 Tim Gruene
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

/**
 * \changes
 * 8/02/2008: changed Scale from 99999 to 9999 to make program more user friendly
 * by leaving gap between l value and large intensities (after discussion
 * with George: data cannot be measured to this accuracy, so scale of 9999
 * is sufficient).
 */
namespace Defs 
{
	/**
	 * \namespace Author
	 * Details about the author
	 */
	namespace Author
	{
		const char* const name  = "Tim Grune";					///< Author's name
		const char* const email = "tg@shelx.uni-ac.gwdg.de";	///< Author's email address
		const char* const affil = "University of Goettingen";	///< Current place of work
	}	// End of namespace Author
	
	/**
	 * \namespace Program
	 * Some constants describing the program
	 */
	namespace Program
	{
		const char* const version = "0.3";						///< Version of mtz2hkl
		const char* const name    = "mtz2hkl";					///< name of the game
		const int     copyright   = 2008;						///< copyright year
	}
	
	/**
	 * \namespace HKLF
	 * Constants that refer to the shelx hklf format
	 */
	namespace HKLF
	{
		const unsigned int Scale = 9999;
	}
}	// End of namespace Defs

#endif /*DEFINES_H_*/
