#ifndef LABEL_H_
#define LABEL_H_

/*
 * mtz2hkl - convert mtz-file to shelx HKL format
 * Copyright (C) 2008 Tim Gruene
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

#include <exception>
#include <sstream>

namespace myExcepts
{
	namespace Label
	{
		class Label: public std::exception
		{
			private:
				const char* what_;
			public:
				Label(const char* text): what_(text) {}
				virtual ~Label() throw(){};
				virtual const char* what() const throw()
				{
					std::ostringstream wii;
					wii << "          Missing or non-unique label for " << what_ << "\n"
						<< "          Please specify.\n";
					return wii.str().c_str();
				}
		};
		
		class RFree: public Label 
		{
			public:
				RFree(): Label("Rfree") {}
		};
		
		class DataInt: public Label 
		{
			public:
				DataInt(): Label("Intensity") {}
		};
		
		class DataAmpl: public Label 
		{
			public:
				DataAmpl(): Label("Amplitude") {}
		};
		
		class NotFound: public Label
		{
			private:
				const char* msg_;
			public:
				NotFound(const char* msg): Label(""), msg_(msg){}
				virtual const char* what() const throw()
				{
					std::ostringstream wii;
					wii << "          No valid entry found for column " << msg_;
					return wii.str().c_str();
				}
		};
					
	}	// End of namespace Label
	
	namespace FileIO 
	{
		class FailedOpen: public std::exception
		{
			private:
				const char* text_;
			public:
				FailedOpen(const char* text): text_(text) {}
				virtual ~FailedOpen() throw() {}
				virtual const char* what() const throw()
				{
					std::ostringstream wii;
					wii << "          Failed to open " << text_;
					return wii.str().c_str();
				}
		};
		
		class MtzOpen: public FailedOpen
		{
			private:
			public:
				MtzOpen(const std::string& filename): 
					FailedOpen(("input mtz-file " + filename).c_str()) {}
				virtual ~MtzOpen() throw() {}
		};
		class HklOpen: public FailedOpen
		{
			private:
			public:
				HklOpen(const std::string& filename):
					FailedOpen (("output hkl-file " + filename).c_str()) {}
				virtual ~HklOpen() throw() {}
		};
	}	// End of namespace FileIO
	
	class ProgError {
		private:
			const char* msg_;
		public:
			ProgError(const char* msg): msg_(msg){}
			virtual ~ProgError() throw() {}
			virtual const char* what() const throw();
	};
	
}	// End of namespace myExcepts

#endif /*LABEL_H_*/
